searchData={"items":[{"type":"module","title":"AbsintheSecurity","doc":"Documentation for `AbsintheSecurity`.","ref":"AbsintheSecurity.html"},{"type":"extras","title":"README","doc":"AbsintheSecurity  provides utilities to improve the security posture of APIs built with  Absinthe GraphQL .","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"Add `absinthe_security` to the `deps` function in your project’s `mix.exs` file:\n\n```elixir\ndefp deps do\n  [\n    {:absinthe_security, \"~> 0.1\"}\n  ]\nend\n```\n\nThen run `mix do deps.get, deps.compile` inside your project’s directory.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"First, initialize `Absinthe.Plug` with a custom configuration:\n\n```elixir\nforward(\"/graphql\",\n  to: Absinthe.Plug,\n  init_opts: MyAppGraphQL.configuration()\n)\n```\n\nYour custom configuration (with all of `AbsintheSecurity`’s checks) might look like this:\n\n```elixir\ndefmodule MyAppGraphQL do\n  def configuration do\n    [schema: MyAppGraphQL.Schema, pipeline: {__MODULE__, :absinthe_pipeline}]\n  end\n\n  def absinthe_pipeline(config, options) do\n    config\n    |> Absinthe.Plug.default_pipeline(options)\n    |> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.IntrospectionCheck)\n    |> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Result, AbsintheSecurity.Phase.FieldSuggestionsCheck)\n    |> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.MaxAliasesCheck)\n    |> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.MaxDepthCheck)\n    |> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.MaxDirectivesCheck)\n  end\nend\n```\n\n### `AbsintheSecurity.Phase.IntrospectionCheck`\n\nDisable schema introspection queries at runtime.\n\n```elixir\nconfig :absinthe_security, AbsintheSecurity.Phase.IntrospectionCheck,\n  enable_introspection: System.get_env(\"GRAPHQL_ENABLE_INTROSPECTION\")\n```\n\n```elixir\n|> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.IntrospectionCheck)\n```\n\n### `AbsintheSecurity.Phase.DisableFieldSuggestions`\n\nDisable field suggestions in responses at runtime.\n\n```elixir\nconfig :absinthe_security, AbsintheSecurity.Phase.FieldSuggestionsCheck,\n  enable_field_suggestions: System.get_env(\"GRAPHQL_ENABLE_FIELD_SUGGESTIONS\")\n```\n\n```elixir\n|> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Result, AbsintheSecurity.Phase.FieldSuggestionsCheck)\n```\n\n### `AbsintheSecurity.Phase.MaxAliasesCheck`\n\nRestrict the number of aliases that can be used in queries.\n\n```elixir\nconfig :absinthe_security, AbsintheSecurity.Phase.MaxAliasesCheck,\n  max_alias_count: 100\n```\n\n```elixir\n|> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.MaxAliasesCheck)\n```\n\n### `AbsintheSecurity.Phase.MaxDepthCheck`\n\nRestrict the depth level that can be used in queries.\n\n```elixir\nconfig :absinthe_security, AbsintheSecurity.Phase.MaxDepthCheck,\n  max_depth_count: 100\n```\n\n```elixir\n|> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.MaxDepthCheck)\n```\n\n### `AbsintheSecurity.Phase.MaxDirectivesCheck`\n\nRestrict the number of directives that can be used in queries.\n\n```elixir\nconfig :absinthe_security, AbsintheSecurity.Phase.MaxDirectivesCheck,\n  max_directive_count: 100\n```\n\n```elixir\n|> Absinthe.Pipeline.insert_after(Absinthe.Phase.Document.Complexity.Result, AbsintheSecurity.Phase.MaxDirectivesCheck)\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - README","doc":"`AbsintheSecurity` is © 2023 [Mirego](https://www.mirego.com) and may be freely distributed under the [New BSD license](http://opensource.org/licenses/BSD-3-Clause). See the [`LICENSE.md`](https://github.com/mirego/absinthe_security/blob/main/LICENSE.md) file.","ref":"readme.html#license"},{"type":"extras","title":"About Mirego - README","doc":"[Mirego](https://www.mirego.com) is a team of passionate people who believe that work is a place where you can innovate and have fun. We’re a team of [talented people](https://life.mirego.com) who imagine and build beautiful Web and mobile applications. We come together to share ideas and [change the world](http://www.mirego.org).\n\nWe also [love open-source software](https://open.mirego.com) and we try to give back to the community as much as we can.","ref":"readme.html#about-mirego"}],"content_type":"text/markdown"}